Enum DiscoveryMessage

pub enum DiscoveryMessage<'a, D: AdvertisementData> {
    Discovery,
    Announce {
        service_port: u16,
        discover_id: u32,
        disconnected: bool,
        adv_data: Cow<'a, D>,
    },
    ExtendAnnouncements,
}

Variants



Discovery

Ping packet used to trigger other endpoints to send Announce packet back



Announce

Tell other endpoints that we are running and available for making connection

Fields

service_port: u16
discover_id: u32
disconnected: bool
adv_data: Cow<'a, D>


ExtendAnnouncements

Request for endpoints on Primary and Backup ports to extend their announcements scope to Backup ports as well