MulticastDiscoverySocket

Struct MulticastDiscoverySocket 

pub struct MulticastDiscoverySocket<D: AdvertisementData> { /* private fields */ }

Implementations

Source

impl<D: AdvertisementData> MulticastDiscoverySocket<D>

pub fn new_discover_only(cfg: &MulticastDiscoveryConfig) -> Result<Self>

Create new socket for multicast discovery. Announcements are disabled (running without service) Enable feature bincode for passing Encode + Decode types as adv_data

pub fn new_with_service( cfg: &MulticastDiscoveryConfig, service_port: u16, initial_adv_data: D, ) -> Result<Self>

Create new socket for multicast discovery. Announcements are enabled depending on config. Enable feature bincode for passing Encode + Decode types as adv_data

pub fn discover_id(&self) -> u32

Returns discover ID. It is generated randomly, and can be used to detect client application restart.

pub fn running_port(&self) -> MulticastRunningPort

pub fn set_announce_en(&mut self, en: bool)

Setting this to false will disable periodic background announcements during poll() Announcements are performed by periodic sending message Announce (and ExtendAnnounce)

pub fn set_discover_replies_en(&mut self, enable: bool)

Setting this to false will disable automatic replies to Discovery messages

pub fn adv_data(&mut self) -> Option<&mut D>

Guaranteed to return Some(&mut D) if was created with Self::new

pub fn discover(&mut self)

Manually discover all clients on main or backup ports (using Discovery message). Results can be collected by running poll.

pub fn poll(&mut self, discover_msg: impl FnMut(PollResult<'_, D>))

Run poll periodically to handle internal discovery mechanisms:

  • Announce messages periodic sending
  • ExtendAnnounce messages periodic sending (if running on backup port)
  • handling incoming messages (and returning discovery results via discover_msg callback)

It is recommended to call this function in a loop with ~100ms sleep